Issue

Struct Issue 

pub struct Issue { /* private fields */ }
A problem of the input.

This is a summary of an Error that can be cloned and stored: its kind, message, location and path and the Violation if a validator rejected the value.

Implementations

Source

impl Issue

pub fn from_error(err: &Error) -> Issue

Creates the issue of an error.

For errors that hold multiple errors (see Error::errors), this is the issue of the first one, see Report::from_error for all of them.

pub fn kind(&self) -> ErrorKind

Returns the kind of the error.

pub fn message(&self) -> &str

Returns the message.

pub fn path(&self) -> Option<&str>

Returns the path of the value (for instance servers[1].port).

The path of the root value is the empty string.

pub fn offset(&self) -> Option<usize>

Returns the byte offset in the input.

pub fn line(&self) -> Option<usize>

Returns the line (1-based).

pub fn column(&self) -> Option<usize>

Returns the column (1-based, in characters).

pub fn violation(&self) -> Option<&Violation>

Returns the violation if a validator rejected the value.