Report

Struct Report 

pub struct Report { /* private fields */ }
All problems of an input.

A report is the result of a Validation, it lists the issues in the order they appear in the input. Its display output lists them one per line.

Implementations

Source

impl Report

pub fn new() -> Report

Creates an empty report.

pub fn from_error(err: &Error) -> Report

Creates the report of the errors an error holds.

pub fn is_empty(&self) -> bool

Returns true if there are no issues.

pub fn len(&self) -> usize

Returns the number of issues.

pub fn issues(&self) -> &[Issue]

Returns the issues.

pub fn iter(&self) -> Iter<'_, Issue> ⓘ

Iterates over the issues.

pub fn push(&mut self, issue: Issue)

Adds an issue.

pub fn resolve_positions(&mut self, source: &[u8])

Resolves the offsets of the issues without lines and columns.

The source is the input the offsets refer to. Issues of values that kept their errors (see Validated) only have lines and columns if the format provides the source (see deser_location). This resolves them otherwise.