pub struct Len<const MIN: usize, const MAX: usize = { usize::MAX }>;Expand description
Requires the length of a string or collection to be in a range.
Both ends are inclusive. Strings count characters, collections items
(see Length). The code of the violation is the name of the
validator: len, min_len (MinLen) or max_len (MaxLen). It
has the parameters min and max (if they are set).
use deser_validate::{Len, MaxLen, Validator};
assert!(Len::<1, 3>::validate("abc").is_ok());
assert_eq!(
Len::<1, 3>::validate("abcd").unwrap_err().message(),
"length must be between 1 and 3"
);
assert!(MaxLen::<2>::validate(&vec![1, 2, 3]).is_err());Trait Implementations