pub struct Report { /* private fields */ }Expand description
All problems of an input.
A report is the result of a Validation, it lists the issues in the
order they appear in the input. Its display output lists them one per
line.
Implementations
Sourceimpl Report
impl Report
Sourcepub fn from_error(err: &Error) -> Report
pub fn from_error(err: &Error) -> Report
Creates the report of the errors an error holds.
Sourcepub fn resolve_positions(&mut self, source: &[u8])
pub fn resolve_positions(&mut self, source: &[u8])
Resolves the offsets of the issues without lines and columns.
The source is the input the offsets refer to. Issues of values
that kept their errors (see Validated) only
have lines and columns if the format provides the source (see
deser_location). This resolves them otherwise.